@@ -3,7 +3,6 @@
 #' @export
 #' @param id (character) The EOL data object identifier
 #' @param usekey (logical) use your API key or not (TRUE or FALSE)
-#' @param asdf (logical) Return "list" or "data.frame". Default: TRUE (return data.frame)
 #' @param key (character) Your EOL API key; can load from .Rprofile if not passed as a parameter
 #' @param verbose (logical); If TRUE the actual taxon queried is printed on the
 #'    console.
@@ -14,13 +13,24 @@
 #' @examples \dontrun{
 #' eol_dataobjects(id = "d72801627bf4adf1a38d9c5f10cc767f")
 #' eol_dataobjects(id = "21929584")
-#' eol_dataobjects(id = "21929584", FALSE)
+#'
+#' # curl options
+#' library("httr")
+#' eol_dataobjects(id = "21929584", config = verbose())
 #' }
-eol_dataobjects <- function(id, asdf = TRUE, usekey = TRUE, key = NULL,
-                            verbose = TRUE, ...) {
+eol_dataobjects <- function(id, usekey = TRUE, key = NULL, verbose = TRUE, ...) {
   if (usekey) key <- getkey(key, "eolApiKey")
-  tt <- GET(file.path(eol_url("data_objects"), paste0(id, ".json")), query = argsnull(tc(list(key = key))))
+  tt <- GET(file.path(eol_url("data_objects"), paste0(id, ".json")), query = argsnull(tc(list(key = key))),
+            ...)
   stop_for_status(tt)
   res <- content(tt, as = "text")
-  jsonlite::fromJSON(res, asdf)
+  tmp <- jsonlite::fromJSON(res)
+  tmp <- nmslwr(tmp)
+  tmp$taxonconcepts <- nmslwr(tmp$taxonconcepts)
+  tmp$dataobjects <- nmslwr(tmp$dataobjects)
+  return(tmp)
+}
+
+nmslwr <- function(x) {
+  setNames(x, tolower(names(x)))
 }
