@@ -10,7 +10,3 @@ test_that("itis_refs returns the correct class", {
   expect_that(two, is_a("list"))
   expect_that(two[[1]], is_a("data.frame"))
 })
-
-test_that("itis_refs returns a message when verbose is TRUE", {
-  expect_message(itis_refs(202385, verbose=TRUE))
-})
\ No newline at end of file
